@@ -1,11 +1,14 @@
 from string import punctuation
+from typing import Type
 
 import pytest
 
 from textual import events, work
+from textual._on import on
 from textual.app import App, ComposeResult
 from textual.binding import Binding
 from textual.containers import Center, Middle
+from textual.css.errors import StylesheetError
 from textual.pilot import OutOfBounds
 from textual.screen import Screen
 from textual.widgets import Button, Label
@@ -395,3 +398,55 @@ async def test_pilot_resize_terminal():
         await pilot.pause()
         assert app.size == (27, 15)
         assert app.screen.size == (27, 15)
+
+
+async def test_fail_early():
+    # https://github.com/Textualize/textual/issues/3282
+    class MyApp(App):
+        CSS_PATH = "foo.tcss"
+
+    app = MyApp()
+    with pytest.raises(StylesheetError):
+        async with app.run_test() as pilot:
+            await pilot.press("enter")
+
+
+async def test_click_by_widget():
+    """Test that click accept a Widget instance."""
+    pressed = False
+
+    class TestApp(CenteredButtonApp):
+        def on_button_pressed(self):
+            nonlocal pressed
+            pressed = True
+
+    app = TestApp()
+    async with app.run_test() as pilot:
+        button = app.query_one(Button)
+        assert not pressed
+        await pilot.click(button)
+        assert pressed
+
+
+@pytest.mark.parametrize("times", [1, 2, 3])
+async def test_click_times(times: int):
+    """Test that Pilot.click() can be called with a `times` argument."""
+
+    events_received: list[Type[events.Event]] = []
+
+    class TestApp(App[None]):
+        def compose(self) -> ComposeResult:
+            yield Label("Click counter")
+
+        @on(events.Click)
+        @on(events.MouseDown)
+        @on(events.MouseUp)
+        def on_label_clicked(self, event: events.Event):
+            events_received.append(event.__class__)
+
+    app = TestApp()
+    async with app.run_test() as pilot:
+        await pilot.click(Label, times=times)
+        assert (
+            events_received == [events.MouseDown, events.MouseUp, events.Click] * times
+        )
